# Copyright 1999-2016. Parallels IP Holdings GmbH. All Rights Reserved.
import os
import pwd
import grp


def drop_privileges(user_name, group_name=None):
    pw = pwd.getpwnam(user_name)
    uid = pw.pw_uid
    gid = grp.getgrnam(group_name).gr_gid if group_name else pw.pw_gid

    try:
        from os import initgroups
        initgroups(user_name, gid)
    except ImportError:
        # Python <= 2.7 compatibility
        os.setgroups([])

    os.setgid(gid)

    try:
        # This module is present only on OSes where HAS_RESOURCE_CONTROLLER is defined
        from plesk_resctrl import resctrl_setuid as setuid
    except ImportError:
        from os import setuid
    setuid(uid)

    if not (os.getuid() == os.geteuid() == uid and os.getgid() == os.getegid() == gid):
        raise RuntimeError("Cannot drop privileges to uid=%s, gid=%s" % (uid, gid))


def chdir_ignore_failure(path, logger=None):
    try:
        os.chdir(path)
        return True
    except OSError as ex:
        if logger is not None:
            logger.info("Failed to chdir to '%s': %s", path, ex)
        return False
