# Copyright 1999-2016. Parallels IP Holdings GmbH. All Rights Reserved.
import os
import logging

_default_log_level = logging.INFO

def setDefaultLevel(loglevel):
    """ Set default log level for all spawned loggers from string or int argument. 

        This method may be used e.g. to set up logger level via --log=INFO option,
        just pass 'INFO' as an argument (preferably) before any actual logging.
    """
    global _default_log_level

    level = loglevel
    if not isinstance(level, int):
        level = getattr(logging, level.upper(), None)
        if not isinstance(level, int):
            raise ValueError('Invalid log level: %s' % loglevel)

    _default_log_level = level
    logging.basicConfig(level=_default_log_level)

def getLogger(name):
    """ Get a logger with a given name flavor. """
    level = _default_log_level
    if os.getenv('PLESK_DEBUG') == '1':
        level = logging.DEBUG

    logging.basicConfig(level=level)
    log = logging.getLogger(name)
    log.setLevel(level)
    return log

# [[[cog
#   import cog
#   funcs = ['debug', 'info', 'warning', 'error', 'critical', 'exception']
#   for func in funcs:
#       cog.outl("""\
#           def %(func)s(msg, *args, **kwargs):
#               logging.%(func)s(msg, *args, **kwargs)
#           """ % { 'func': func })
# ]]]
def debug(msg, *args, **kwargs):
    logging.debug(msg, *args, **kwargs)

def info(msg, *args, **kwargs):
    logging.info(msg, *args, **kwargs)

def warning(msg, *args, **kwargs):
    logging.warning(msg, *args, **kwargs)

def error(msg, *args, **kwargs):
    logging.error(msg, *args, **kwargs)

def critical(msg, *args, **kwargs):
    logging.critical(msg, *args, **kwargs)

def exception(msg, *args, **kwargs):
    logging.exception(msg, *args, **kwargs)

# [[[end]]] (checksum: eeb547d19c962a082c690a75578134fc)

# Poor man's testsuite
if __name__ == '__main__':
    setDefaultLevel('warning')
    log = getLogger('plesk_log')
    log.debug("Shown debug if PLESK_DEBUG")
    log.info("Shown info if PLESK_DEBUG")
    log.warning("Shown warning")
    log.error("Shown error")
    log.critical("Shown critical")
    warning("Complex arguments: string = %s, int = %d" % ('value', 123))
    error("Complex dict arguments: string = %(field1)s, int = %(field2)d" % {'field1': 'value', 'field2': 123})
    try:
        setDefaultLevel('unknown level')
    except:
        exception("Shown exception")

# vim: ts=4 sts=4 sw=4 et :
